#!/bin/bash

export COMPONENT_HASH=a458fbaf10cf0a5ed1addf4c8075edde2c3ed31d
PKG_VERSION=3.1.0+cdh6.1.1
FULL_VERSION=3.1.0-cdh6.1.1
BASE_VERSION=3.1.0
PKG_RELEASE=875250
CDH_CUSTOMER_PATCH=p0
CDH_PARCEL_CUSTOM_VERSION=3.1.0+cdh6.1.1-875250.xenial
